==> nnetsauce-0.2.1.tar.gz: nnetsauce-0.2.1/nnetsauce/simulation/sobol.py <==

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")


# Import the low-level C/C++ module
#if __package__ or "." in __name__:
    
    try:
        
        from ._sobol import *
            
    except:        
            
        import _sobol
        
    else:
        
        try:
            import builtins as __builtin__
        except ImportError:
            import __builtin__
        
        def _swig_repr(self):
            try:
                strthis = "proxy of " + self.this.__repr__()
            except __builtin__.Exception:
                strthis = ""
            return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)
        
        
        def _swig_setattr_nondynamic_instance_variable(set):
            def set_instance_attr(self, name, value):
                if name == "thisown":
                    self.this.own(value)
                elif name == "this":
                    set(self, name, value)
                elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
                    set(self, name, value)
                else:
                    raise AttributeError("You cannot add instance attributes to %s" % self)
            return set_instance_attr
        
        
        def _swig_setattr_nondynamic_class_variable(set):
            def set_class_attr(cls, name, value):
                if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
                    set(cls, name, value)
                else:
                    raise AttributeError("You cannot add class attributes to %s" % cls)
            return set_class_attr
        
        
        def _swig_add_metaclass(metaclass):
            """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
            def wrapper(cls):
                return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
            return wrapper
        
        
        class _SwigNonDynamicMeta(type):
            """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
            __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)
        
        
        
        def i8_bit_hi1(n):
            return _sobol.i8_bit_hi1(n)
        
        def i8_bit_lo0(n):
            return _sobol.i8_bit_lo0(n)
        
        def i8_max(i1, i2):
            return _sobol.i8_max(i1, i2)
        
        def i8_min(i1, i2):
            return _sobol.i8_min(i1, i2)
        
        def i8_sobol(dim_num, seed, quasi):
            return _sobol.i8_sobol(dim_num, seed, quasi)
        
        def i8_sobol_generate(m, n, skip):
            return _sobol.i8_sobol_generate(m, n, skip)
        
        def i8_uniform(b, c, seed):
            return _sobol.i8_uniform(b, c, seed)
        
        def r8_abs(x):
            return _sobol.r8_abs(x)
        
        def r8_nint(x):
            return _sobol.r8_nint(x)
        
        def r8_uniform_01(seed):
            return _sobol.r8_uniform_01(seed)
        
        def tau_sobol(dim_num):
            return _sobol.tau_sobol(dim_num)
        
        def timestamp():
            return _sobol.timestamp()

==> nnetsauce-0.3.0.tar.gz: nnetsauce-0.3.0/nnetsauce/simulation/sobol.py <==
from sys import version_info as _swig_python_version_info

if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

    # Import the low-level C/C++ module
    # if __package__ or "." in __name__:

    try:

        from ._sobol import *

    except:

        import _sobol

    else:

        try:
            import builtins as __builtin__
        except ImportError:
            import __builtin__

        def _swig_repr(self):
            try:
                strthis = "proxy of " + self.this.__repr__()
            except __builtin__.Exception:
                strthis = ""
            return "<%s.%s; %s >" % (
                self.__class__.__module__,
                self.__class__.__name__,
                strthis,
            )

        def _swig_setattr_nondynamic_instance_variable(set):
            def set_instance_attr(self, name, value):
                if name == "thisown":
                    self.this.own(value)
                elif name == "this":
                    set(self, name, value)
                elif hasattr(self, name) and isinstance(
                    getattr(type(self), name), property
                ):
                    set(self, name, value)
                else:
                    raise AttributeError(
                        "You cannot add instance attributes to %s"
                        % self
                    )

            return set_instance_attr

        def _swig_setattr_nondynamic_class_variable(set):
            def set_class_attr(cls, name, value):
                if hasattr(cls, name) and not isinstance(
                    getattr(cls, name), property
                ):
                    set(cls, name, value)
                else:
                    raise AttributeError(
                        "You cannot add class attributes to %s"
                        % cls
                    )

            return set_class_attr

        def _swig_add_metaclass(metaclass):
            """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""

            def wrapper(cls):
                return metaclass(
                    cls.__name__,
                    cls.__bases__,
                    cls.__dict__.copy(),
                )

            return wrapper

        class _SwigNonDynamicMeta(type):
            """Meta class to enforce nondynamic attributes (no new attributes) for a class"""

            __setattr__ = _swig_setattr_nondynamic_class_variable(
                type.__setattr__
            )

        def i8_bit_hi1(n):
            return _sobol.i8_bit_hi1(n)

        def i8_bit_lo0(n):
            return _sobol.i8_bit_lo0(n)

        def i8_max(i1, i2):
            return _sobol.i8_max(i1, i2)

        def i8_min(i1, i2):
            return _sobol.i8_min(i1, i2)

        def i8_sobol(dim_num, seed, quasi):
            return _sobol.i8_sobol(dim_num, seed, quasi)

        def i8_sobol_generate(m, n, skip):
            return _sobol.i8_sobol_generate(m, n, skip)

        def i8_uniform(b, c, seed):
            return _sobol.i8_uniform(b, c, seed)

        def r8_abs(x):
            return _sobol.r8_abs(x)

        def r8_nint(x):
            return _sobol.r8_nint(x)

        def r8_uniform_01(seed):
            return _sobol.r8_uniform_01(seed)

        def tau_sobol(dim_num):
            return _sobol.tau_sobol(dim_num)

        def timestamp():
            return _sobol.timestamp()
